@@ -127,7 +127,7 @@ class FSFError(Exception):
 class FEATFSFDesign(object):
     """The ``FEATFSFDesign`` class encapsulates the design matrix from a FEAT
     analysis. This class is intended to be used for FEAT analyses generated
-    with FSL 5.0.9 and older.
+    with FSL 5.0.9 and newer.
     """
 
     def __init__(self, featDir, settings=None, loadVoxelwiseEVs=True):
@@ -169,30 +169,15 @@ class FEATFSFDesign(object):
         if level == 1: getEVs = getFirstLevelEVs
         else:          getEVs = getHigherLevelEVs
 
-        self.__settings = collections.OrderedDict(settings.items())
-        self.__design   = np.array(designMatrix)
-        self.__numEVs   = self.__design.shape[1]
-        self.__evs      = getEVs(featDir, self.__settings, self.__design)
+        self.__loadVoxEVs = loadVoxelwiseEVs
+        self.__settings   = collections.OrderedDict(settings.items())
+        self.__design     = np.array(designMatrix)
+        self.__numEVs     = self.__design.shape[1]
+        self.__evs        = getEVs(featDir, self.__settings, self.__design)
 
         if len(self.__evs) != self.__numEVs:
             raise FSFError('Number of EVs does not match design.mat')
 
-        # Load the voxelwise images now,
-        # so they're ready to be used by
-        # the getDesign method.
-        for ev in self.__evs:
-
-            if not isinstance(ev, (VoxelwiseEV, VoxelwiseConfoundEV)):
-                continue
-
-            ev.image = None
-
-            # The path to some voxelwise
-            # EVs may not be present -
-            # see the VoxelwisEV class.
-            if loadVoxelwiseEVs and (ev.filename is not None):
-                ev.image = fslimage.Image(ev.filename)
-
 
     def getEVs(self):
         """Returns a list containing the :class:`EV` instances that represent
@@ -224,16 +209,103 @@ class FEATFSFDesign(object):
             if not isinstance(ev, (VoxelwiseEV, VoxelwiseConfoundEV)):
                 continue
 
-            if ev.image is None:
+            if (not self.__loadVoxEVs) or (ev.filename is None):
                 log.warning('Voxel EV image missing '
                             'for ev {}'.format(ev.index))
                 continue
 
-            design[:, ev.index] = ev.image[x, y, z, :]
+            design[:, ev.index] = ev.getData(x, y, z)
 
         return design
 
 
+class VoxelwiseEVMixin(object):
+    """Mixin class for voxelwise EVs.
+
+    ``VoxelwiseEVMixin`` instances contain the following attributes:
+
+    ============ ======================================================
+    ``filename`` Path to the image file containing the data for this EV
+    ``image``    Reference to the :class:`.Image` object
+    ============ ======================================================
+
+    Some FSL tools (e.g. `PNM
+    <https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/PNM>`_) generate *compressed*
+    voxelwise EVs, where there is only one voxel per slice. For example,
+    if the input data has shape ``(x, y, z, t)``, and slices are acquired
+    along the Z plane, voxelwise EV files generated by PNM will have shape
+    ``(1, 1, z, t)``.
+
+    Therefore, using the :meth:`getData` method is preferable to accessing
+    the :meth:`image` directly, as ``getData`` will check for compressed
+    images, and adjust the voxel coordinates accordingly.
+    """
+
+    def __init__(self, filename):
+        """Create a ``VoxelwiseEVMixin``.
+
+        :arg filename: Path to the file containing the data for this
+                       ``VoxelwiseEV``.
+        """
+        if op.exists(filename):
+            self.__filename = filename
+        else:
+            log.warning('Voxelwise EV file does not '
+                        'exist: {}'.format(filename))
+            self.__filename = None
+
+        self.__image = None
+
+
+    def __del__(self):
+        """Clears any reference to the voxelwise EV image. """
+        self.__image = None
+
+
+    @property
+    def filename(self):
+        """Returns the path to the image file containing the data for this EV.
+        """
+        return self.__filename
+
+
+    @property
+    def image(self):
+        """Returns the :class:`.Image` containing the voxelwise EV data. """
+
+        if self.__filename is None:
+            return None
+
+        if self.__image is not None:
+            return self.__image
+
+        self.__image = fslimage.Image(self.__filename, mmap=False)
+        return self.__image
+
+
+    def getData(self, x, y, z):
+        """Returns the data at the specified voxel, taking into account
+        compressed voxelwise EVs.
+        """
+        image = self.image
+
+        if image is None:
+            return None
+
+        dx, dy, dz = image.shape[:3]
+
+        # "Compressed" images have one voxel
+        # per slice, i.e. they have shape
+        # [1, 1, nslices, ntimepoints] (if
+        # Z is the slice plane).
+        if sum((dx == 1, dy == 1, dz == 1)) == 2:
+            if dx == 1: x = 0
+            if dy == 1: y = 0
+            if dz == 1: z = 0
+
+        return image[x, y, z, :]
+
+
 class EV(object):
     """Class representing an explanatory variable in a FEAT design matrix.
 
@@ -291,7 +363,7 @@ class BasisFunctionEV(NormalEV):
     pass
 
 
-class VoxelwiseEV(NormalEV):
+class VoxelwiseEV(NormalEV, VoxelwiseEVMixin):
     """Class representing an EV with different values for each voxel in the
     analysis.
 
@@ -300,14 +372,15 @@ class VoxelwiseEV(NormalEV):
 
     ============ ======================================================
     ``filename`` Path to the image file containing the data for this EV
+    ``image``    Reference to the :class:`.Image` object
     ============ ======================================================
 
     .. note:: The file for voxelwise EVs in a higher level analysis are not
               copied into the FEAT directory, so if the user has removed them,
               or moved the .gfeat directory, the file path here will not be
               valid. Therefore, a ``VoxelwiseEV`` will test to see if the
-              file exists, and will set the ``filename`` attribute to ``None``
-              it it does not exist.
+              file exists, and will set the ``filename`` and ``image``
+              attributes to ``None`` it it does not exist.
     """
 
     def __init__(self, realIdx, origIdx, title, filename):
@@ -322,12 +395,7 @@ class VoxelwiseEV(NormalEV):
                        ``VoxelwiseEV``.
         """
         NormalEV.__init__(self, realIdx, origIdx, title)
-
-        if op.exists(filename):
-            self.filename = filename
-        else:
-            log.warning('Voxelwise EV file does not exist: '.format(filename))
-            self.filename = None
+        VoxelwiseEVMixin.__init__(self, filename)
 
 
 class ConfoundEV(EV):
@@ -378,7 +446,7 @@ class MotionParameterEV(EV):
         self.motionIndex = motionIndex
 
 
-class VoxelwiseConfoundEV(EV):
+class VoxelwiseConfoundEV(EV, VoxelwiseEVMixin):
     """Class representing a voxelwise confound EV.
 
     ``VoxelwiseConfoundEV`` instances contain the following attributes (in
@@ -388,6 +456,7 @@ class VoxelwiseConfoundEV(EV):
     ``voxIndex`` Index of this ``VoxelwiseConfoundEV`` (starting from 0) in
                  relation to all other voxelwise confound EVs.
     ``filename`` Path to the image file containing the data for this EV
+    ``image``    Reference to the :class:`.Image` object
     ============ ==========================================================
     """
     def __init__(self, index, voxIndex, title, filename):
@@ -399,17 +468,13 @@ class VoxelwiseConfoundEV(EV):
                         ``VoxelwiseConfoundEV`` in relation to all other
                         voxelwise confound EVs.
         :arg title:     Name of this ``VoxelwiseConfoundEV``.
+        :arg filename:  Path to the file containing the data for this
+                        ``VoxelwiseConfoundEV``.
         """
         EV.__init__(self, index, title)
+        VoxelwiseEVMixin.__init__(self, filename)
         self.voxIndex = voxIndex
 
-        if op.exists(filename):
-            self.filename = filename
-        else:
-            log.warning('Voxelwise confound EV file '
-                        'does not exist: '.format(filename))
-            self.filename = None
-
 
 def getFirstLevelEVs(featDir, settings, designMat):
     """Derives the EVs for the given first level FEAT analysis.
@@ -547,7 +612,7 @@ def getFirstLevelEVs(featDir, settings, designMat):
         # Create the voxelwise confound EVs.
         # We make a name for the EV from the
         # file name.
-        for i, (f, l) in enumerate(zip(voxConfFiles, voxConfLocs)):
+        for i, f in enumerate(voxConfFiles):
             title = op.basename(fslimage.removeExt(f))
             evs.append(VoxelwiseConfoundEV(len(evs), i, title, f))
 
