@@ -16,9 +16,15 @@ from __future__ import print_function
 
 import os.path        as op
 import                   sys
+import                   warnings
+
 import fsl.utils.path as fslpath
-import fsl.utils.imcp as imcp
-import fsl.data.image as fslimage
+
+# See atlasq.py for explanation
+with warnings.catch_warnings():
+    warnings.filterwarnings("ignore", category=FutureWarning)
+    import fsl.utils.imcp as imcp
+    import fsl.data.image as fslimage
 
 
 usage = """Usage:
@@ -43,26 +49,32 @@ def main(argv=None):
         argv = sys.argv[1:]
 
     if len(argv) < 2:
-        raise RuntimeError(usage)
+        print(usage)
+        return 1
 
     srcs = argv[:-1]
     dest = argv[ -1]
 
     if len(srcs) > 1 and not op.isdir(dest):
-        raise RuntimeError(usage)
+        print(usage)
+        return 1
 
-    srcs = fslpath.removeDuplicates(srcs,
-                                    allowedExts=fslimage.ALLOWED_EXTENSIONS,
-                                    fileGroups=fslimage.FILE_GROUPS)
+    try:
+        srcs = [fslimage.fixExt(s) for s in srcs]
+        srcs = fslpath.removeDuplicates(
+            srcs,
+            allowedExts=fslimage.ALLOWED_EXTENSIONS,
+            fileGroups=fslimage.FILE_GROUPS)
 
-    for src in srcs:
-        imcp.imcp(src, dest, useDefaultExt=True, overwrite=True)
+        for src in srcs:
+            imcp.imcp(src, dest, useDefaultExt=True, overwrite=True)
+
+    except Exception as e:
+        print(str(e))
+        return 1
+
+    return 0
 
 
 if __name__ == '__main__':
-
-    try:
-        main()
-    except Exception as e:
-        print(e)
-        sys.exit(1)
+    sys.exit(main())
